getChild method

Node? getChild(
  1. int index
)

Returns the index-th direct child of the scene root, or null if the index is out of range or the scene has no children.

Implementation

fb.Node? getChild(int index) {
  int? childIndex = children?[index];
  if (childIndex == null) {
    return null;
  }
  return nodes?[childIndex];
}