GltfAnimation class

Constructors

GltfAnimation({String? name, List<GltfAnimationChannel> channels = const [], List<GltfAnimationSampler> samplers = const []})

Properties

channels List<GltfAnimationChannel>
final
hashCode int
The hash code for this object.
no setterinherited
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
samplers List<GltfAnimationSampler>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited