GltfAnimationSampler class

Constructors

GltfAnimationSampler({required int input, required int output, String interpolation = 'LINEAR'})

Properties

hashCode int
The hash code for this object.
no setterinherited
input int
final
interpolation String
final
output int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited