GltfBufferView class

Constructors

GltfBufferView({required int buffer, required int byteLength, int byteOffset = 0, int? byteStride})

Properties

buffer int
final
byteLength int
final
byteOffset int
final
byteStride int?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited