GltfSampler class

Constructors

GltfSampler({int? magFilter, int? minFilter, int wrapS = 10497, int wrapT = 10497})

Properties

hashCode int
The hash code for this object.
no setterinherited
magFilter int?
final
minFilter int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wrapS int
final
wrapT int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited