GltfSkin class

Constructors

GltfSkin({String? name, int? inverseBindMatrices, int? skeleton, List<int> joints = const []})

Properties

hashCode int
The hash code for this object.
no setterinherited
inverseBindMatrices int?
final
joints List<int>
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skeleton int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited