Aabb3 class

Axis-aligned bounding box in some local space (typically the space of the vertex positions on a primitive, or the local space of a node).

Properties

hashCode int
The hash code for this object.
no setterinherited
max Vec3
no setter
min Vec3
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
unpack() Aabb3T

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

pack(Builder fbBuilder, Aabb3T? object) int

Constants

reader → const Reader<Aabb3>