MeshPrimitiveBuilder class

Constructors

MeshPrimitiveBuilder(Builder fbBuilder)

Properties

fbBuilder Builder
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addBoundsAabb(int offset) int
addBoundsSphere(int offset) int
addIndicesOffset(int? offset) int
addMaterialOffset(int? offset) int
addSkinnedPoseUnionAabb(int offset) int
addVerticesOffset(int? offset) int
addVerticesType(VertexBufferTypeId? verticesType) int
begin() → void
finish() int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited