Scene class
- Available extensions
Properties
-
animations
→ List<
Animation> ? -
no setter
-
children
→ List<
int> ? -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
nodes
→ List<
Node> ? -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
textures
→ List<
Texture> ? -
no setter
- transform → Matrix?
-
no setter
Methods
-
getChild(
int index) → Node? -
Available on Scene, provided by the SceneHelpers extension
Returns theindex-th direct child of the scene root, ornullif the index is out of range or the scene has no children. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
transformAsMatrix4(
) → Matrix4 -
Available on Scene, provided by the SceneHelpers extension
Returns the scene's root transform as aMatrix4, or the identity matrix when the scene has no transform set. -
unpack(
) → SceneT
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited