Sphere class

Bounding sphere in the same space as an associated Aabb3.

Properties

center Vec3
no setter
hashCode int
The hash code for this object.
no setterinherited
radius double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
unpack() SphereT

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

pack(Builder fbBuilder, SphereT? object) int

Constants

reader → const Reader<Sphere>