GltfAccessor class
Constructors
- GltfAccessor({required GltfComponentType componentType, required int count, required GltfAccessorType type, int? bufferView, int byteOffset = 0, bool normalized = false})
Properties
- bufferView → int?
-
final
- byteOffset → int
-
final
- componentType → GltfComponentType
-
final
- count → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- normalized → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → GltfAccessorType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited