GltfAnimationChannel class

Constructors

GltfAnimationChannel({required int sampler, required int? targetNode, required String targetPath})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampler int
final
targetNode int?
final
targetPath String
One of 'translation', 'rotation', 'scale', 'weights'.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited