GltfComponentType enum
Component types from glTF spec section 5.1.1.
Values
- byte_ → const GltfComponentType
-
const GltfComponentType(5120, 1, true) - unsignedByte → const GltfComponentType
-
const GltfComponentType(5121, 1, false) - short → const GltfComponentType
-
const GltfComponentType(5122, 2, true) - unsignedShort → const GltfComponentType
-
const GltfComponentType(5123, 2, false) - unsignedInt → const GltfComponentType
-
const GltfComponentType(5125, 4, false) - float → const GltfComponentType
-
const GltfComponentType(5126, 4, true)
Properties
- bytes → int
-
final
- glValue → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signed → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
-
values
→ const List<
GltfComponentType> - A constant List of the values in this enum, in order of their declaration.