GltfDocument class
In-memory representation of the parts of glTF 2.0 that flutter_scene
consumes. Field names match the glTF spec (camelCase). Indexes into other
arrays are stored as int? and resolved at use time.
Constructors
-
GltfDocument({int? scene, List<
GltfScene> scenes = const [], List<GltfNode> nodes = const [], List<GltfMesh> meshes = const [], List<GltfAccessor> accessors = const [], List<GltfBufferView> bufferViews = const [], List<GltfBuffer> buffers = const [], List<GltfMaterial> materials = const [], List<GltfTexture> textures = const [], List<GltfImage> images = const [], List<GltfSampler> samplers = const [], List<GltfSkin> skins = const [], List<GltfAnimation> animations = const []})
Properties
-
accessors
→ List<
GltfAccessor> -
final
-
animations
→ List<
GltfAnimation> -
final
-
buffers
→ List<
GltfBuffer> -
final
-
bufferViews
→ List<
GltfBufferView> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
images
→ List<
GltfImage> -
final
-
materials
→ List<
GltfMaterial> -
final
-
meshes
→ List<
GltfMesh> -
final
-
nodes
→ List<
GltfNode> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
samplers
→ List<
GltfSampler> -
final
- scene → int?
-
final
-
scenes
→ List<
GltfScene> -
final
-
skins
→ List<
GltfSkin> -
final
-
textures
→ List<
GltfTexture> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited