GltfMaterial class
Constructors
-
GltfMaterial({String? name, GltfPbrMetallicRoughness? pbrMetallicRoughness, GltfTextureInfo? normalTexture, GltfTextureInfo? occlusionTexture, GltfTextureInfo? emissiveTexture, List<
double> emissiveFactor = const [0.0, 0.0, 0.0], String alphaMode = 'OPAQUE', double alphaCutoff = 0.5, bool doubleSided = false, bool unlit = false})
Properties
- alphaCutoff → double
-
final
- alphaMode → String
-
final
- doubleSided → bool
-
final
-
emissiveFactor
→ List<
double> -
final
- emissiveTexture → GltfTextureInfo?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
final
- normalTexture → GltfTextureInfo?
-
final
- occlusionTexture → GltfTextureInfo?
-
final
- pbrMetallicRoughness → GltfPbrMetallicRoughness?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unlit → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited