GltfMeshPrimitive class
Properties
-
attributes
→ Map<String, int>
-
Maps glTF attribute names ('POSITION', 'NORMAL', 'TEXCOORD_0',
'COLOR_0', 'JOINTS_0', 'WEIGHTS_0', 'TANGENT') to accessor indexes.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
indices
→ int?
-
final
-
material
→ int?
-
final
-
mode
→ int
-
Primitive topology. 4 = TRIANGLES (the only mode flutter_scene supports).
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited