GltfNode class
Constructors
Properties
-
children
→ List<
int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- matrix → Matrix4?
-
If matrix is set, translation/rotation/scale are ignored.
final
- mesh → int?
-
final
- name → String?
-
final
- rotation → Quaternion?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → Vector3?
-
final
- skin → int?
-
final
- translation → Vector3?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited