GltfTextureInfo class

Constructors

GltfTextureInfo({required int index, int texCoord = 0, double? scale, double? strength})

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double?
Set on normal textures (otherwise null).
final
strength double?
Set on occlusion textures (otherwise null).
final
texCoord int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited