Sphere class
Bounding sphere in the same space as an associated Aabb3.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
unpack(
) → SphereT
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited